@@ -51,20 +51,22 @@
 #define 	MCE_PATH   "/com/nokia/mce/signal"
 #define 	MCE_INTERFACE   "com.nokia.mce.signal"
 #define 	MCE_STATE   "sig_call_state_ind"
-#define         CALL_SERVICE "com.nokia.csd.Call"
-#define         CALL_PATH "/com/nokia/csd/call/1"
-#define         CALL_INTERFACE "com.nokia.csd.Call.Instance"
-#define         CALL_END_PATH "/com/nokia/csd/call"
-#define         CALL_END_INTERFACE "com.nokia.csd.Call"
-#define         CALL_ANSWER "Answer"
-#define         CALL_END "Release"
+#define     CALL_SERVICE "com.nokia.csd.Call"
+#define     CALL_PATH "/com/nokia/csd/call/1"
+#define     CALL_INTERFACE "com.nokia.csd.Call.Instance"
+#define     CALL_END_PATH "/com/nokia/csd/call"
+#define     CALL_END_INTERFACE "com.nokia.csd.Call"
+#define     CALL_ANSWER "Answer"
+#define     CALL_END "Release"
 
+#define 	AVATAR_SIZE 216
 
 struct _Slide2AnswerStatusPluginPrivate
 {
   GtkWidget* call_window;
   GtkWidget* call_window_avatar;
   GtkWidget* call_window_name_label;
+  GtkWidget* call_window_number_label;
   GtkWidget* call_window_slider;
   gboolean is_voip_call;
   DBusGConnection *dbus_conn;
@@ -173,7 +175,7 @@ _slider_changed(GtkRange* range,
     gtk_widget_hide(GTK_WIDGET(plugin->priv->call_window));
     _accept_call(plugin);
   }
-  else if(value<0.1)
+  else if(value<-0.9)
   {
     gtk_widget_hide(GTK_WIDGET(plugin->priv->call_window));
     _reject_call(plugin);
@@ -187,7 +189,7 @@ _slider_changed_stopped(GtkWidget *widget,
 			gpointer user_data)
 {
   g_warning("stopped\n");
-  gtk_range_set_value(GTK_RANGE(user_data), 0.5);
+  gtk_range_set_value(GTK_RANGE(user_data), 0.0);
 }
 
 static void
@@ -198,16 +200,21 @@ _create_slide2answer_window(Slide2AnswerStatusPlugin* status_plugin)
    
   GdkPixbuf* pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
 					       "general_default_avatar",
-					       216, GTK_ICON_LOOKUP_NO_SVG, NULL);
+					       AVATAR_SIZE, GTK_ICON_LOOKUP_NO_SVG, NULL);
   status_plugin->priv->call_window_avatar = gtk_image_new_from_pixbuf(pixbuf);
 
   g_object_unref(pixbuf);
   status_plugin->priv->call_window_name_label = gtk_label_new("");
+  hildon_helper_set_logical_font(status_plugin->priv->call_window_name_label, "LargeSystemFont");
+  status_plugin->priv->call_window_number_label = gtk_label_new("");
+  hildon_helper_set_logical_font(status_plugin->priv->call_window_number_label, "SmallSystemFont");
+  
   status_plugin->priv->call_window_slider = hildon_gtk_hscale_new();
   //gtk_range_set_jump_to_position(GTK_RANGE(status_plugin->priv->call_window_slider), FALSE);
-  gtk_range_set_value(GTK_RANGE(status_plugin->priv->call_window_slider), 0.5);
   gtk_widget_set_name(status_plugin->priv->call_window_slider,
-		      "sui-tklock-slider");
+		      "bidirectional-slider-horizontal");
+  gtk_range_set_range(GTK_RANGE(status_plugin->priv->call_window_slider), -1.0, 1.0);              
+  gtk_range_set_value(GTK_RANGE(status_plugin->priv->call_window_slider), 0.0);
   
   GtkWidget* accept_button = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT,
 					       HILDON_BUTTON_ARRANGEMENT_VERTICAL);
@@ -229,12 +236,16 @@ _create_slide2answer_window(Slide2AnswerStatusPlugin* status_plugin)
   g_signal_connect(status_plugin->priv->call_window_slider, "button-release-event", G_CALLBACK(_slider_changed_stopped), status_plugin->priv->call_window_slider);
 
   GtkWidget* contact_box = gtk_hbox_new(FALSE, 0);
+  GtkWidget* contact_info_box = gtk_vbox_new(FALSE, 0);
   GtkWidget* button_box = gtk_hbox_new(FALSE, 0);
   GtkWidget* content = gtk_vbox_new(FALSE, 0);
   gtk_container_add(GTK_CONTAINER(status_plugin->priv->call_window), 
 		    content);
   gtk_box_pack_start(GTK_BOX(contact_box), status_plugin->priv->call_window_avatar, TRUE, TRUE, 0);
-  gtk_box_pack_start(GTK_BOX(contact_box), status_plugin->priv->call_window_name_label, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(contact_info_box), status_plugin->priv->call_window_name_label, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(contact_info_box), status_plugin->priv->call_window_number_label, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(contact_box), contact_info_box, TRUE, TRUE, 0);
+  
   gtk_box_pack_start(GTK_BOX(button_box), reject_button, TRUE, TRUE, 0);
   gtk_box_pack_start(GTK_BOX(button_box), accept_button, TRUE, TRUE, 0);
   gtk_box_pack_start(GTK_BOX(content), contact_box, TRUE, TRUE, 0);
@@ -265,7 +276,7 @@ _show_slide2answer_window(Slide2AnswerStatusPlugin* plugin)
   }
   else
   {
-    gtk_range_set_value(GTK_RANGE(plugin->priv->call_window_slider), 0.5);
+    gtk_range_set_value(GTK_RANGE(plugin->priv->call_window_slider), 0.0);
     gtk_widget_show(GTK_WIDGET(plugin->priv->call_window));
   }
 }
@@ -341,10 +352,11 @@ _set_unknowncaller_data(Slide2AnswerStatusPlugin* status_plugin, const gchar* id
 {
   gtk_label_set_text(GTK_LABEL(status_plugin->priv->call_window_name_label),
 		             identifier);
-
+  gtk_label_set_text(GTK_LABEL(status_plugin->priv->call_window_number_label),
+		             "");
   GdkPixbuf* pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
                                                "general_default_avatar",
-                                               216, GTK_ICON_LOOKUP_NO_SVG, NULL);
+                                               AVATAR_SIZE, GTK_ICON_LOOKUP_NO_SVG, NULL);
 
   gtk_image_set_from_pixbuf(GTK_IMAGE(status_plugin->priv->call_window_avatar),
 			                pixbuf);
@@ -352,23 +364,30 @@ _set_unknowncaller_data(Slide2AnswerStatusPlugin* status_plugin, const gchar* id
 }
 
 static void
-_set_contact_data(Slide2AnswerStatusPlugin* status_plugin, OssoABookContact* contact)
+_set_contact_data(Slide2AnswerStatusPlugin* status_plugin, OssoABookContact* contact, const gchar* identifier)
 {
   gtk_label_set_text(GTK_LABEL(status_plugin->priv->call_window_name_label),
 		     osso_abook_contact_get_display_name(contact));
-  GdkPixbuf* pixbuf = osso_abook_contact_get_photo(contact);
+  gtk_label_set_text(GTK_LABEL(status_plugin->priv->call_window_number_label),
+  		     identifier);      
+  GdkPixbuf* pixbuf = osso_abook_avatar_get_image_scaled(OSSO_ABOOK_AVATAR(contact),
+						AVATAR_SIZE,
+						AVATAR_SIZE,
+						FALSE);
+             
+  /*GdkPixbuf* pixbuf = osso_abook_contact_get_photo(contact);
   if(!pixbuf)
   {
     pixbuf = osso_abook_avatar_get_image_scaled(OSSO_ABOOK_AVATAR(contact),
-						216,
-						216,
+						AVATAR_SIZE,
+						AVATAR_SIZE,
 						FALSE);
-  }
+  }*/
   if(!pixbuf)
   {
     gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
 			     "general_default_avatar",
-			     216, GTK_ICON_LOOKUP_NO_SVG, NULL);
+			     AVATAR_SIZE, GTK_ICON_LOOKUP_NO_SVG, NULL);
   }
 
   gtk_image_set_from_pixbuf(GTK_IMAGE(status_plugin->priv->call_window_avatar),
@@ -467,7 +486,7 @@ handle_new_channel(TpConnection *proxy,
       if(contact)
       {
 	OssoABookContact* abook_contact = OSSO_ABOOK_CONTACT(contact->data);
-	_set_contact_data(plugin, abook_contact);
+	_set_contact_data(plugin, abook_contact, identifier);
 	while(contact)
 	{
 	  OssoABookContact* abook_contact = OSSO_ABOOK_CONTACT(contact->data);
